@@ -22,6 +22,7 @@ import shutil
 import sys
 import unittest
 import warnings
+import getpass
 
 # Below is general helper stuff that Python uses in `unittests`.  As these
 # not meant for users, and could change without notice, include them
@@ -1135,6 +1136,73 @@ class TestCWD(_TestGlob):
 
         self.assert_equal(glob.glob('EF', root_dir=pathlib.Path(self.tempdir)), ['EF'])
 
+    @pytest.mark.skipif(not glob.SUPPORT_DIR_FD, reason="dir_fd is not supported on this system")
+    def test_cwd_fd_dir(self):
+        """Test file descriptor."""
+
+        dir_fd = os.open(self.tempdir, os.O_RDONLY | os.O_DIRECTORY)
+        self.assert_equal(glob.glob('EF', dir_fd=dir_fd), ['EF'])
+        os.close(dir_fd)
+
+    @pytest.mark.skipif(not glob.SUPPORT_DIR_FD, reason="dir_fd is not supported on this system")
+    def test_cwd_dir_fd_globmatch(self):
+        """Test file descriptor on `globmatch`."""
+
+        dir_fd = os.open(self.tempdir, os.O_RDONLY | os.O_DIRECTORY)
+        self.assert_equal(glob.globmatch('EF', 'EF', dir_fd=dir_fd, flags=glob.REALPATH), True)
+        os.close(dir_fd)
+
+    @pytest.mark.skipif(glob.SUPPORT_DIR_FD, reason="dir_fd is supported on this system")
+    def test_cwd_dir_fd_globmatch_unsupported(self):
+        """Test file descriptor on unsupported system."""
+
+        # Windows doesn't support `dir_fd`, let's fabricate a scenario and verify it doesn't match.
+        dir_fd = 1
+        self.assert_equal(glob.globmatch('EF', 'EF', dir_fd=dir_fd, flags=glob.REALPATH), False)
+
+    @pytest.mark.skipif(not glob.SUPPORT_DIR_FD, reason="dir_fd is not supported on this system")
+    def test_cwd_dir_fd_globmatch_no_follow(self):
+        """Test file descriptor with `globmatch`, but cover link logic."""
+
+        dir_fd = os.open(self.tempdir, os.O_RDONLY | os.O_DIRECTORY)
+        self.assert_equal(
+            glob.globmatch('a/bcd/EF', 'a/**/EF', dir_fd=dir_fd, flags=glob.REALPATH | glob.GLOBSTAR),
+            True
+        )
+        os.close(dir_fd)
+
+    @pytest.mark.skipif(glob.SUPPORT_DIR_FD, reason="dir_fd is supported on this system")
+    def test_cwd_dir_fd_globmatch_no_follow_unsupported(self):
+        """Test file descriptor with `globmatch` on unsupported systems, but cover link logic."""
+
+        # Windows doesn't support `dir_fd`, let's fabricate a scenario and verify it doesn't match.
+        dir_fd = 1
+        self.assert_equal(
+            glob.globmatch('a/bcd/EF', 'a/**/EF', dir_fd=dir_fd, flags=glob.REALPATH | glob.GLOBSTAR),
+            False
+        )
+
+    @pytest.mark.skipif(not glob.SUPPORT_DIR_FD, reason="dir_fd is not supported on this system")
+    def test_cwd_dir_fd_root_dir(self):
+        """Test file descriptor and root directory together."""
+
+        dir_fd = os.open(self.tempdir, os.O_RDONLY | os.O_DIRECTORY)
+        root_dir = 'a'
+        self.assert_equal(glob.glob('bcd/EF', dir_fd=dir_fd, root_dir=root_dir), [os.path.join('bcd', 'EF')])
+        os.close(dir_fd)
+
+    @pytest.mark.skipif(not glob.SUPPORT_DIR_FD, reason="dir_fd is not supported on this system")
+    def test_cwd_dir_fd_root_dir_globmatch_no_follow(self):
+        """Test file descriptor and root directory on `globmatch`, but cover link logic."""
+
+        dir_fd = os.open(self.tempdir, os.O_RDONLY | os.O_DIRECTORY)
+        root_dir = 'a'
+        self.assert_equal(
+            glob.globmatch('bcd/EF', '**/EF', dir_fd=dir_fd, root_dir=root_dir, flags=glob.REALPATH | glob.GLOBSTAR),
+            True
+        )
+        os.close(dir_fd)
+
 
 class TestCase(_TestGlob):
     """Test files in the current working directory."""
@@ -1475,7 +1543,10 @@ class TestTilde(unittest.TestCase):
     def test_tilde_user(self):
         """Test tilde user cases."""
 
-        user = os.path.basename(os.path.expanduser('~'))
+        try:
+            user = getpass.getuser()
+        except ModuleNotFoundError:
+            user = os.path.basename(os.path.expanduser('~'))
 
         files = os.listdir(os.path.expanduser('~{}'.format(user)))
         self.assertEqual(len(glob.glob('~{}/*'.format(user), flags=glob.T | glob.D)), len(files))
